import { useDispatch, useSelector } from 'react-redux';
import { useEffect, useState } from 'react';
import { Form } from 'react-bootstrap';

export default function CampaignScript() {
    const dispatch = useDispatch();
    const selectedProduct = useSelector((state) => state.brands.selectedProduct);
    const [activeTab, setActiveTab] = useState('collaborationInfo');

    useEffect(() => {
        console.log(selectedProduct);
    }, [selectedProduct]);

    return (
        selectedProduct?.id && (
            <div className='product-script'>
                <div className='product-details shadow-xs'>
                    <div className='product-details-header'>
                        <div className='product-details-header-title'>{selectedProduct.name}</div>
                        <div className='product-details-header-pid'>PID: {selectedProduct.id}</div>
                    </div>
                    <div className='product-details-body'>
                        <div className='product-img'></div>
                        <div className='product-detail-list'>
                            <div className='product-detail-item'>
                                <div className='product-detail-item-value'>{selectedProduct.commission}</div>
                                <div className='product-detail-item-label'>Commission Rate</div>
                            </div>
                            <div className='product-detail-item'>
                                <div className='product-detail-item-value'>{selectedProduct.availableSamples}</div>
                                <div className='product-detail-item-label'>Available Samples</div>
                            </div>
                            <div className='product-detail-item'>
                                <div className='product-detail-item-value'>{selectedProduct.price}</div>
                                <div className='product-detail-item-label'>Sales Price</div>
                            </div>
                            <div className='product-detail-item'>
                                <div className='product-detail-item-value'>{selectedProduct.stock}</div>
                                <div className='product-detail-item-label'>Stock</div>
                            </div>
                            <div className='product-detail-item'>
                                <div className='product-detail-item-value'>{selectedProduct.sold}</div>
                                <div className='product-detail-item-label'>Items Sold</div>
                            </div>
                            <div className='product-detail-item'>
                                <div className='product-detail-item-value'>{selectedProduct.rating}</div>
                                <div className='product-detail-item-label'>Product Rating</div>
                            </div>
                            <div className='product-detail-item'>
                                <div className='product-detail-item-value'>{selectedProduct.collabCreators}</div>
                                <div className='product-detail-item-label'>Collab Creators</div>
                            </div>
                            <div className='product-detail-item'>
                                <div className='product-detail-item-value'>{selectedProduct.gmv}</div>
                                <div className='product-detail-item-label'>GMV Achieved</div>
                            </div>
                            <div className='product-detail-item'>
                                <div className='product-detail-item-value'>{selectedProduct.reviews}</div>
                                <div className='product-detail-item-label'>Views Achieved</div>
                            </div>
                        </div>
                    </div>
                </div>
                <div className='product-script-switches tab-switches'>
                    <div
                        className={`tab-switch-item ${activeTab === 'collaborationInfo' ? 'active' : ''}`}
                        onClick={() => setActiveTab('collaborationInfo')}
                    >
                        Collaboration Info
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'campaigns' ? 'active' : ''}`}
                        onClick={() => setActiveTab('campaigns')}
                    >
                        Campaigns & Collaborated Creators
                    </div>
                </div>
                <div className='product-script-video-req'>
                    <Form className='video-req-form'>
                        <div className='form-header'>Video Posting Requirement</div>
                        <Form.Group>
                            <Form.Label>Product Selling Point</Form.Label>
                            <Form.Control
                                type='textarea'
                                as='textarea'
                                rows={3}
                                placeholder='吸力强、有效除菌、香薰片功能、价格更优惠、两种颜色'
                            />
                        </Form.Group>
                        <Form.Group>
                            <Form.Label>Example Videos</Form.Label>
                            <Form.Control
                                type='textarea'
                                as='textarea'
                                rows={3}
                                placeholder='https://mcnmza4kafoj.feishu.cn/drive/folder/HzhWfGvWtlCBqIduwfLczQ9Cnyb'
                            />
                        </Form.Group>
                        <Form.Group>
                            <Form.Label>Video Posting Suggestion</Form.Label>
                            <Form.Control
                                type='textarea'
                                as='textarea'
                                rows={3}
                                placeholder='开头引人+产品亮点+CTA呼吁/时长30~50s左右'
                            />
                        </Form.Group>
                        <Form.Group>
                            <Form.Label>Video Acceptance Standard</Form.Label>
                            <Form.Control
                                type='textarea'
                                as='textarea'
                                rows={3}
                                placeholder='1.场景：包括不限于厨房、卫生间、衣柜；在橱柜下方和洗手台下方安装橱柜灯、衣柜等安全及方便需求。场景展示要有黑暗环境对比HOOK。
2.红人必须要表达卖点（以下卖点按优先级排列，达人任意选择提到至少三个卖点即可）
电池大续航能力强可以（必须提到）（可用字幕展示）
容易安装（有磁铁）（必须提到）（要拍出安装过程）
开启人体感应模式 （必须提到）（可视觉展示）
可充电
亮度高，且可调节
加分卖点：
  视频需说明购买理由以及使用感受（例如：老人家晚上更安全，宝妈晚上起床更便捷安全等等购买理由）
3.正确的hashtags 以及正确@官方账号'
                            />
                        </Form.Group>
                    </Form>
                </div>
            </div>
        )
    );
}
