import { createAsyncThunk, createSlice } from '@reduxjs/toolkit';

const mockProducts = [
    {
        id: 1,
        name: 'Name',
        commission: '15%',
        openCollab: '12%',
        availableSamples: 10,
        price: '$78.90 - $118.90',
        stock: 884,
        sold: 732,
        rating: 4.2,
        reviews: 58,
        collabCreators: 40,
        tiktokShop: true,
        gmv: '$4k - $10k',
    },
    {
        id: 2,
        name: 'Name',
        commission: '15%',
        openCollab: '12%',
        availableSamples: 10,
        price: '$78.90 - $118.90',
        stock: 884,
        sold: 732,
        rating: 4.2,
        reviews: 58,
        collabCreators: 40,
        tiktokShop: true,
        gmv: '$4k - $10k',
    },
    {
        id: 3,
        name: 'Name',
        commission: '15%',
        openCollab: '12%',
        availableSamples: 10,
        price: '$78.90 - $118.90',
        stock: 884,
        sold: 732,
        rating: 4.2,
        reviews: 58,
        collabCreators: 40,
        tiktokShop: true,
        gmv: '$4k - $10k',
    },
];

const mockCampaigns = [
    {
        id: 1,
        name: 'SUNLINK拍拍灯',
        service: '达人短视频-付费',
        creators: 10,
        creator_type: '带货类达人',
        creator_level: ['L2', 'L3'],
        category: ['家居', '生活', '数码'],
        gmv: '$4k - $10k',
        followers: 10000,
        views: '500 - 10.5k',
        budget: '$10 - $150',
        products: mockProducts,
    },
    {
        id: 2,
        name: 'MINISO',
        service: '达人短视频-付费',
        creators: 10,
        creator_type: '带货类达人',
        creator_level: ['L2', 'L3'],
        category: ['家居', '生活', '数码'],
        gmv: '$4k - $10k',
        followers: 10000,
        views: '500 - 10.5k',
        budget: '$10 - $150',
        products: mockProducts,
    },
];

const mockBrands = [
    {
        id: 1,
        name: 'Sunlink',
        category: 'furniture',
        collab: '3',
        creators: 20,
        source: 'TKS Official',
        description: 'Description 1',
        website: 'https://www.brand1.com',
        campaigns: mockCampaigns,
        products: mockProducts,
    },
    {
        id: 2,
        name: 'MINISO',
        category: 'furniture',
        collab: '5',
        creators: 30,
        source: 'TKS Official',
        description: 'Description 1',
        website: 'https://www.brand1.com',
        campaigns: mockCampaigns,
        products: mockProducts,
    },
];

export const fetchBrands = createAsyncThunk('brands/fetchBrands', async () => {
    // const response = await fetch('https://api.example.com/brands');
    await new Promise((resolve) => setTimeout(resolve, 500));
    console.log('fetchBrands');

    return mockBrands;
});

const initialState = {
    brands: [],
    status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
    error: null,
    selectedBrand: {},
    selectedCampaign: {},
    selectedProduct: {},
};

const brandsSlice = createSlice({
    name: 'brands',
    initialState,
    reducers: {
        selectBrand: (state, action) => {
            state.selectedBrand = action.payload;
        },
        findBrandById: (state, action) => {
            state.selectedBrand = state.brands.find((brand) => brand.id.toString() === action.payload);
        },
        findCampaignById: (state, action) => {
            const { brandId, campaignId } = action.payload;
            const brand = state.brands?.find((b) => b.id.toString() === brandId);

            state.selectedBrand = brand;
            state.selectedCampaign = brand?.campaigns?.find((c) => c.id.toString() === campaignId) || {};
        },
        findProductById: (state, action) => {
            const { brandId, campaignId, productId } = action.payload;
            const brand = state.brands?.find((b) => b.id.toString() === brandId);
            const campaign = brand?.campaigns?.find((c) => c.id.toString() === campaignId);
            const product = campaign?.products?.find((p) => p.id.toString() === productId.toString());
            console.log(brand, campaign, product);
            state.selectedProduct = product;
        },
    },
    extraReducers: (builder) => {
        builder
            .addCase(fetchBrands.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(fetchBrands.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.brands = action.payload;
            })
            .addCase(fetchBrands.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.error.message;
            });
    },
});

export const { selectBrand, findBrandById, findCampaignById, findProductById } = brandsSlice.actions;

export default brandsSlice.reducer;
